"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cdk_1 = require("@aws-cdk/cdk");
const log = require("./log_messages");
function getGitData(props) {
    return {
        branch: props.branch,
        owner: getOwner(props),
        repo: getRepo(props),
        secret: getSecret(props),
    };
}
exports.getGitData = getGitData;
function getSecret(props) {
    return getTokenDirect(props) || props.secretParameter || noToken();
}
function noToken() {
    log.noGithubTokenFound();
    return new cdk_1.Secret('noToken');
}
function getTokenDirect(props) {
    return props.token && new cdk_1.Secret(props.token);
}
function getOwner(props) {
    return props.owner || (props.pkg && getOwnerPkgJson(props.pkg)) || noOwner();
}
function getOwnerPkgJson(pkg) {
    const repoUrl = pkg.repository && pkg.repository.url;
    const isGithubUrl = repoUrl && repoUrl.indexOf('github.com') > -1;
    return isGithubUrl && getOwnerFromURL(repoUrl);
}
function getOwnerFromURL(url) {
    const path = url.substring(url.indexOf('github.com') + 10);
    return path.substring(1, path.indexOf('/', 1));
}
function noOwner() {
    log.noOwnerFound();
    return 'noOwner';
}
function getRepo(props) {
    return props.repo || (props.pkg && getRepoPkgJson(props.pkg)) || noRepo();
}
function getRepoPkgJson(pkg) {
    const repoUrl = pkg.repository && pkg.repository.url;
    const isGithubUrl = repoUrl && repoUrl.indexOf('github.com') > -1;
    const repoUrlRepoName = isGithubUrl && getRepoFromURL(repoUrl);
    return repoUrlRepoName || pkg.name;
}
function noRepo() {
    log.noGitRepoFound();
    return `noRepo`;
}
function getRepoFromURL(url) {
    const path = url.substring(url.indexOf('github.com') + 10);
    return path.slice(path.indexOf('/', 1) + 1, path.indexOf('.git'));
}
//# sourceMappingURL=get_github_creds.js.map